import vue from 'rollup-plugin-vue'
import typescript from 'rollup-plugin-typescript2'
import pkg from '../package.json'
import css from 'rollup-plugin-css-porter'
import scss from 'rollup-plugin-scss'
import resolve from '@rollup/plugin-node-resolve'
import copy from 'rollup-plugin-copy'

export default [
  {
    input: 'src/index.ts', // our source file
    output: {
      format: 'esm',
      file: 'lib/test-ui-ts-lib.esm.js',
      sourcemap: true
    },
    external: [
      ...Object.keys(pkg.dependencies || {}),
      'tslib',
      'vue',
      'vue-class-component',
      'vue-property-decorator'
    ],
    plugins: [
      copy({
        targets: [
          { src: 'src/styles/*', dest: 'lib/styles' }
        ]
      }),
      typescript({
        typescript: require('typescript'),
        objectHashIgnoreUnknownHack: true,
        module: 'esnext',

        tsconfig: 'tsconfig.json',
        tsconfigOverride: { exclude: ['node_modules', 'src/plugins', 'tests', 'src/stories'] }
      }),
      // commonjs(),

      // [Rollup Plugin Vue](https://rollup-plugin-vue.vuejs.org/)
      vue({
        css: true, // Dynamically inject css as a <style> tag
        compileTemplate: true // Explicitly convert template to render function
      }),
      scss(),
      css(),
      resolve()
      // terser() // minifies generated bundles

      // del({
      //   targets: 'lib/main.d.ts',
      //   hook: 'generateBundle'
      // })
    ]
  }
]
